/*
 * i18n.c: Internationalization
 *
 * See the main source file 'vdr.c' for copyright information and
 * how to reach the author.
 *
 * $Id: i18n.c 1.86.1.2 2002/06/10 15:37:09 kls Exp $
 *
 * Slovenian  translations provided by Miha Setina <mihasetina@softhome.net> and Matjaz Thaler <matjaz.thaler@guest.arnes.si>
 * Italian    translations provided by Alberto Carraro <bertocar@tin.it>
 * Dutch      translations provided by Arnold Niessen <niessen@iae.nl> <arnold.niessen@philips.com>
 * Portuguese translations provided by Paulo Lopes <pmml@netvita.pt>
 * French     translations provided by Jean-Claude Repetto <jc@repetto.org>
 * Norwegian  translations provided by Jrgen Tvedt <pjtvedt@online.no> and Truls Slevigen <truls@slevigen.no>
 * Finnish    translations provided by Hannu Savolainen <hannu@opensound.com>
 * Polish     translations provided by Michael Rakowski <mrak@gmx.de>
 * Spanish    translations provided by Ruben Nunez Francisco <ruben.nunez@tang-it.com>
 * Greek      translations provided by Dimitrios Dimitrakos <mail@dimitrios.de>
 * Swedish    translations provided by Tomas Prybil <tomas@prybil.se>
 * Romanian   translations provided by Paul Lacatus <paul@campina.iiruc.ro>
 *
 */

/*
 * How to add a new language:
 *
 * 1. Announce your translation action on the Linux-DVB mailing
 *    list to avoid duplicate work.
 * 2. Increase the value of 'NumLanguages'.
 * 3. Insert a new line in every member of the 'Phrases[]' array,
 *    containing the translated text for the new language.
 *    For example, assuming you want to add the Italian language,
 *
 *       { "English",
 *         "Deutsch",
 *       },
 *
 *    would become
 *
 *       { "English",
 *         "Deutsch",
 *         "Italiano",
 *       },
 *
 *    and so on. Append your language after the last existing language
 *    and write the name of your language in your language (not in English,
 *    which means that it should be 'Italiano', not 'Italian').
 *    Note that only the characters defined in 'fontosd.c' will
 *    be available!
 * 4. Compile VDR and test the new language by switching to it
 *    in the "Setup" menu.
 * 5. Send the modified 'i18n.c' file to <kls@cadsoft.de> to have
 *    it included in the next version of VDR.
 *
 * In case an English phrase is used in more than one context (and might need
 * different translations in other languages) it can be preceeded with an
 * arbitrary string to describe its context, separated from the actual phrase
 * by a '$' character (see for instance "Button$Stop" vs. "Stop").
 * Of course this means that no English phrase may contain the '$' character!
 * If this should ever become necessary, the existing '$' would have to be
 * replaced with something different...
 */

#include "i18n.h"
#include <stdio.h>
#include "config.h"
#include "tools.h"

const int NumLanguages = 14;

typedef const char *tPhrase[NumLanguages];

const tPhrase Phrases[] = {
  // The name of the language (this MUST be the first phrase!):
  { "English",
    "Deutsch",
    "Slovenski",
    "Italiano",
    "Nederlands",
    "Portugus",
    "Franais",
    "Norsk",
    "Suomi",
    "Polski",
    "Espaol",
    "Ellinika",
    "Svenska",
    "Romaneste",
  },
  // Menu titles:
  { "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
    "VDR",
  },
  { "Schedule",
    "Programm",
    "Urnik",
    "Programmi",
    "Gids",
    "Programao",
    "Programmes",
    "Programmer",
    "Ohjelmat",
    "Program",
    "Programa",
    "Programma",
    "Program",
    "Program",
  },
  { "Channels",
    "Kanle",
    "Kanali",
    "Canali",
    "Kanalen",
    "Canais",
    "Chanes",
    "Kanaler",
    "Kanavat",
    "Kanaly",
    "Canales",
    "Kanalia",
    "Kanaler",
    "Canale",
  },
  { "Timers",
    "Timer",
    "Termini",
    "Timer",
    "Timers",
    "Timers",
    "Programmation",
    "Timere",
    "Ajastin",
    "Timery",
    "Timer",
    "Programmatismos",
    "Timers",
    "Timere",
  },
  { "Recordings",
    "Aufzeichnungen",
    "Posnetki",
    "Registrazioni",
    "Opnames",
    "Gravaes",
    "Enregistrements",
    "Opptak",
    "Nauhoitteet",
    "Nagrania",
    "Grabaciones",
    "Egrafes",
    "Inspelningar",
    "Inregistrari",
  },
  { "Setup",
    "Einstellungen",
    "Nastavitve",
    "Opzioni",
    "Instellingen",
    "Configurar",
    "Configuration",
    "Konfigurasjon",
    "Asetukset",
    "Nastawy",
    "Configuracin",
    "Rithmisis",
    "Instllningar",
    "Setari",
  },
  { "Commands",
    "Befehle",
    "Ukazi",
    "Comandi",
    "Commando's",
    "Comandos",
    "Commandes",
    "Kommandoer",
    "Komennot",
    "Rozkazy",
    "rdenes",
    "Entoles",
    "Kommandon",
    "Comenzi",
  },
  { "Edit channel",
    "Kanal editieren",
    "Uredi kanal",
    "Modifica canale",
    "Kanaal aanpassen",
    "Modificar canal",
    "Modifier une chane",
    "Editer kanal",
    "Muokkaa kanavaa",
    "Ustawienie kanalu",
    "Modificar canal",
    "Prosarmoges kanaliou",
    "ndra kanal",
    "Editare canale",
  },
  { "Edit timer",
    "Timer editieren",
    "Uredi termin",
    "Modifica timer",
    "Timer veranderen",
    "Modificar timer",
    "Changer la programmation",
    "Editer timer",
    "Muokkaa ajastusta",
    "Ustawienie timerow",
    "Modificar timer",
    "Prosarmoges programmatismou",
    "ndra timer",
    "Editare timere",
  },
  { "Event",
    "Sendung",
    "Oddaja",
    "Eventi",
    "Uitzending",
    "Evento",
    "Evnement",
    "Hendelse",
    "Tapahtuma",
    "Audycja",
    "Evento",
    "Ekpompi",
    "Sndning",
    "Evenimente",
  },
  { "Summary",
    "Inhalt",
    "Vsebina",
    "Sommario",
    "Inhoud",
    "Resumo",
    "Rsum",
    "Sammendrag",
    "Yhteenveto",
    "Zawartosc",
    "Resmen",
    "Periexomeno",
    "Sammandrag",
    "Cuprins",
  },
  { "Schedule - %s",
    "Programm - %s",
    "Urnik - %s",
    "Programma - %s",
    "Programma - %s",
    "Programa - %s",
    "Programmes - %s",
    "Program Guide - %s",
    "Ohjelma - %s",
    "Program - %s",
    "Programa - %s",
    "Programma - %s",
    "Program - %s",
    "Program - %s",
  },
  { "What's on now?",
    "Was luft jetzt?",
    "Kaj je na sporedu?",
    "In programmazione",
    "Wat is er nu?",
    "Programa actual?",
    "Programmes en cours",
    "Hvilket program sendes n?",
    "Nykyinen ohjelma",
    "Program biezacy",
    "Qu hay ahora?",
    "Ti pezi tora",
    "Vilket program snds nu?",
    "Programul actual?",
  },
  { "What's on next?",
    "Was luft als nchstes?",
    "Kaj sledi?",
    "Prossimi programmi",
    "Wat komt er hierna?",
    "Prximo Programa?",
    "Prochains programmes",
    "Hvilket program er neste?",
    "Seuraava ohjelma",
    "Program nastepny",
    "Qu hay proximo?",
    "Ti tha peksi meta",
    "Vilket r nsta program?",
    "Programul urmator?",
  },
  // Button texts (should not be more than 10 characters!):
  { "Edit",
    "Editieren",
    "Uredi",
    "Modifica",
    "Verander",
    "Modificar",
    "Modifier",
    "Editer",
    "Muuta",
    "Edycja",
    "Modificar",
    "Prosarmogi",
    "ndra",
    "Modificare",
  },
  { "New",
    "Neu",
    "Novo",
    "Nuovo",
    "Nieuw",
    "Novo",
    "Nouveau",
    "Ny",
    "Uusi",
    "Nowy",
    "Nuevo",
    "Neo",
    "Ny",
    "Nou",
  },
  { "Delete",
    "Lschen",
    "Odstrani",
    "Cancella",
    "Verwijder",
    "Apagar",
    "Supprimer",
    "Slett",
    "Poista",
    "Usunac",
    "Borrar",
    "Swisimo",
    "Ta bort",
    "Sterge",
  },
  { "Mark",
    "Markieren",
    "Oznaci",
    "Marca",
    "Verplaats",
    "Marcar",
    "Marquer",
    "Marker",
    "Merkitse",
    "Zaznaczyc",
    "Marcar",
    "Markarisma",
    "Mrk",
    "Marcheaza",
  },
  { "On/Off",
    "Ein/Aus",
    "Vklop/Izklop",
    "On/Off",
    "Aan/Uit",
    "On/Off",
    "Marche/Arr",
    "Av/P",
    "Pll/Pois",
    "Zal./ Wyl.",
    "On/Off",
    "Energo/Klisto",
    "P/Av",
    "Pornit/Oprit",
  },
  { "Record",
    "Aufnehmen",
    "Posnemi",
    "Registra",
    "Opnemen",
    "Gravar",
    "Enregistre",
    "Ta opp",
    "Nauhoita",
    "Nagrywac",
    "Grabar",
    "Egrafi",
    "Inspelning",
    "Inregistrare",
  },
  { "Play",
    "Wiedergabe",
    "Predavajaj",
    "Riproduci",
    "Afspelen",
    "Play",
    "Lire",
    "Spill av",
    "Toista",
    "Odtwarzac",
    "Play",
    "Anametadosi",
    "Spela upp",
    "Redare",
  },
  { "Rewind",
    "Anfang",
    "Zacetek",
    "Da inizio",
    "Naar begin",
    "Rebobinar",
    "Retour",
    "Spol tilbake",
    "Takaisinkel.",
    "Poczatek",
    "Rebobinar",
    "Arxi",
    "terspolning",
    "Inapoi",
  },
  { "Button$Stop",
    "Beenden",
    "Ustavi",
    "Stop",
    "Eindigen",
    "Parar",
    "Arrt",
    "Stopp",
    "Pysyt",
    "Zakonczyc",
    "Parar",
    "Terma",
    "Stopp",
    "Stop",
  },
  { "Resume",
    "Weiter",
    "Nadaljuj",
    "Riprendi",
    "Verder",
    "Continuar",
    "Reprendre",
    "Fortsett",
    "Jatka",
    "Dalej",
    "Continuar",
    "Sinexia",
    "Fortstt",
    "Reia",
  },
  { "Summary",
    "Inhalt",
    "Vsebina",
    "Sommario",
    "Inhoud",
    "Resumo",
    "Rsum",
    "Sammendrag",
    "Yhteenveto",
    "Zawartosc",
    "Resumen",
    "Periexomeno",
    "Sammandrag",
    "Cuprins",
  },
  { "Open",
    "ffnen",
    "Odpri",
    "Apri",
    "Openen",
    "Abrir",
    "Ouvrir",
    "pne",
    "Avaa",
    "Otworzyc",
    "Abrir",
    "Anigma",
    "ppna",
    "Deschide",
  },
  { "Switch",
    "Umschalten",
    "Preklopi",
    "Cambia",
    "Selecteer",
    "Seleccionar",
    "Regarder",
    "Skift til",
    "Valitse",
    "Przelaczyc",
    "Cambiar",
    "Alagi",
    "Byt",
    "Schimba",
  },
  { "Now",
    "Jetzt",
    "Sedaj",
    "Adesso",
    "Nu",
    "Agora",
    "Maintenant",
    "N",
    "Nyt",
    "Teraz",
    "Ahora",
    "Tora",
    "Nu",
    "Acum",
  },
  { "Next",
    "Nchste",
    "Naslednji",
    "Prossimo",
    "Hierna",
    "Proximo",
    "Aprs",
    "Neste",
    "Seuraava",
    "Nastepny",
    "Siguiente",
    "Epomeno",
    "Nsta",
    "Urmator",
  },
  { "Button$Schedule",
    "Programm",
    "Urnik",
    "Programma",
    "Programma",
    "Programao",
    "Programme",
    "Programmer",
    "Ohjelmisto",
    "Program",
    "Programa",
    "Programma",
    "Program",
    "Program",
  },
  { "Language",
    "Sprache",
    "Jezik",
    "Linguaggio",
    "Taal",
    "Linguagem",
    "Langue",
    "Sprk",
    "Kieli",
    "Jezyk",
    "Lengua",
    "Glosa",
    "Sprk",
    "Limba",
  },
  { "Eject",
    "Auswerfen",
    "Izvrzi",
    "Eject",
    "Eject",
    "Ejectar",
    "Ejection",
    "Eject",
    "Avaa",
    "Wyrzucenie",
    "Eyectar",
    "Apovoli",
    "Mata ut",
    "Ejecteaza",
  },
  { "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
    "ABC/abc",
  },
  { "Insert",
    "Einfgen",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Isodos",
    "Infoga",
    "Insereaza",
  },
  { "Overwrite",
    "berschreiben",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Epanagrafi",
    "Skriv ver",
    "Suprascrie",
  },
  // Confirmations:
  { "Delete channel?",
    "Kanal lschen?",
    "Odstrani kanal?",
    "Cancello il canale?",
    "Kanaal verwijderen?",
    "Apagar o canal?",
    "Supprimer la chane?",
    "Slette kanal?",
    "Poistetaanko kanava?",
    "Usunac kanal?",
    "Eliminar canal?",
    "Na sviso to kanali?",
    "Ta bort kanalen?",
    "Sterg canalul?",
  },
  { "Delete timer?",
    "Timer lschen?",
    "Odstani termin?",
    "Cancello il timer?",
    "Timer verwijderen?",
    "Apagar o timer?",
    "Supprimer la programmation?",
    "Slette timer?",
    "Poistetaanko ajastus?",
    "Usunac timer?",
    "Eliminar timer?",
    "Svisimo tou programmitismou?",
    "Ta bort timern?",
    "Sterg timer-ul?",
  },
  { "Delete recording?",
    "Aufzeichnung lschen?",
    "Odstrani posnetek?",
    "Cancello la registrazione?",
    "Opname verwijderen?",
    "Apagar a gravao?",
    "Supprimer l'enregistrement?",
    "Slette opptak?",
    "Poistetaanko nauhoitus?",
    "Usunac nagranie?",
    "Eliminar grabacion?",
    "Svisimo tis egrafis?",
    "Ta bort inspelningen?",
    "Sterg inregistrarea?",
  },
  { "Timer still recording - really delete?",
    "Timer zeichnet auf - trotzdem lschen?",
    "Snemanje po terminu - zares odstrani?",
    "Timer in regestazione - cancello?",
    "Timer neemt nog op - toch verwijderen?",
    "Timer activo - tm a certeza que quer apagar?",
    "Enregistrement en cours - confirmez la suppression",
    "Timer gjr opptak - vil du slette likevel?",
    "Ajastin nauhoittaa - poistetaanko silti?",
    "Nagrywanie w trakcie - napewno usunac?",
    "Timer activo - de verdad eliminarlo?",
    "Ginete akoma programmatismeni egrafi - na svisti sigoura?",
    "Timerstyrd inspelning pgr - Avbryta nd?",
    "Timer-ul in inregistrare - sterg?",
  },
  { "Stop recording?",
    "Aufzeichnung beenden?",
    "Koncaj snemanje?",
    "Fermo la registrazione?",
    "Opname stoppen?",
    "Parar Gravao?",
    "Arrter l'enregistrement?",
    "Stoppe opptak?",
    "Pysytetnk nauhoitus?",
    "Zakonczyc nagranie?",
    "Parar grabacin?",
    "Akirosi egrafis?",
    "Stanna inspelning?",
    "Opresc inregistrarea?",
  },
  { "on primary interface",
    "auf dem primren Interface",
    "na primarni napravi",
    "su interfaccia primaria",
    "op eerste interface",
    "no interface primrio",
    "sur la carte primaire",
    "p frste enhet",
    "pvastaanottimella",
    "na pierwszym interfejsie",
    "en interface primario",
    "stin protevon karta",
    "frn det frsta enheten?",
    "pe prima interfata",
  },
  { "Cancel editing?",
    "Schneiden abbrechen?",
    "Zelite prekiniti urejanje?",
    "Annullo la modifica?",
    "Bewerken afbreken?",
    "Cancelar Modificaes?",
    "Annuler les modifications?",
    "Avbryte redigering?",
    "Peruutetaanko muokkaus?",
    "Zakonczyc montaz?",
    "Cancelar modificacin?",
    "Akirosi alagon?",
    "Avbryta editeringen?",
    "Opresc editarea?",
  },
  { "Really restart?",
    "Wirklich neu starten?",
    "Zares ponoven zagon",
    "Eseguo un restart?",
    "Werkelijk opnieuw starten?",
    "Tem a certeza que quer reiniciar?",
    "Redmarrer?",
    "Vil du virkelig starte p nytt?",
    "Aloitetaanko varmasti alusta?",
    "Rzeczywiscie nowy start?",
    "De verdad reiniciar?",
    "Na gini sigoura epanekinisi?",
    "Vill du verkligen starta om?",
    "Esti sigur de repornire?",
  },
  { "Recording - restart anyway?",
    "Aufnahme luft - trotzdem neu starten?",
    "Snemanje - zares ponoven zagon",
    "In registrazione - restart comunque?",
    "Opname loopt - toch opnieuw starten?",
    "Em gravao - quer mesmo reiniciar?",
    "Enregistrement en cours - redmarrer?",
    "Gjr opptak - starte p nytt likevel?",
    "Nauhoitus kynniss - aloitetaanko alusta?",
    "Nagrywanie w trakcie - rzeczywiscie nowy start?",
    "Grabando - reiniciar?",
    "Ginete egrafi - na gini epanekinisi sigoura?",
    "Inspelning pgr, vill du starta om i alla fall?",
    "In inregistrare - repornesc?",
  },
  { "Recording - shut down anyway?",
    "Aufnahme luft - trotzdem ausschalten?",
    "Snemanje - zares izklopi?",
    "In registrazione - spengo comunque?",
    "Opname loopt - toch uitschakelen?",
    "Em gravao - quer mesmo desligar?",
    "Enregistrement en cours - confirmez l'arrt",
    "Gjr opptak - sl av likevel?",
    "Nauhoitus kesken - lopetetaanko se?",
    "Nagrywanie w trakcie - mimo to wylaczyc?",
    "Grabando - apagar?",
    "Ginete egrafi - na stamatisi i litourgia sigoura?",
    "Inspelning pgr, vill du avbryta i alla fall?",
    "In inregistrare - opresc?",
  },
  { "Recording in %d minutes, shut down anyway?",
    "Aufnahme in %d Minuten - trotzdem ausschalten?",
    "Snemanje cez %d minut, zares izklopi?",
    "Registrazione fra %d minuti - spengo comunque?",
    "Opname in %d minuten - toch uitschakelen?",
    "Em gravao dentro de %d minutos - quer mesmo desligar?",
    "Enregistrement dans %d minutes - confirmez l'arrt",
    "Skal gjre opptak om %d minutter - sl av likevel?",
    "Nauhoitus alkaisi %d min. kuluttua - sammutetaanko silti?",
    "Nagrywanie za %d minut - mimo to wylaczyc?",
    "Grabando en %d minutos, de verdad cortar?",
    "Anamenete egrafi se %d lepta - na stamatisi i litourgia sigoura?",
    "Inspelning startar om %d minuter, vill du avsluta?",
    "Inregistrez in %d minute, opresc?",
  },
  { "Press any key to cancel shutdown",
    "Taste drcken um Shutdown abzubrechen",
    "Pritisni katerikoli gumb za preklic izklopa",
    "Un tasto per annullare lo spegnimento",
    "Druk een toets om shutdown af te breken",
    "Pressione qualquer tecla para cancelar",
    "Appuyez sur une touche pour annuler l'arrt",
    "Trykk en tast for ikke  sl av",
    "Peruuta pysytys painamalla jotakin nppint",
    "Dowolny przycisk zatrzyma wylaczanie",
    "Pulse una tecla para interrumpir corte",
    "Piese ena pliktro na stamatisi to katevasma",
    "Tryck valfri knapp fr att avbryta nedstngning",
    "Apasa orice tasta pentru a anula inchiderea",
  },
  // Channel parameters:
  { "Name",
    "Name",
    "Naziv",
    "Nome",
    "Naam",
    "Nome",
    "Nom",
    "Navn",
    "Nimi",
    "Nazwa",
    "Nombre",
    "Onoma",
    "Namn",
    "Nume",
  },
  { "Frequency",
    "Frequenz",
    "Frekvenca",
    "Frequenza",
    "Frequentie",
    "Frequncia",
    "Frquence",
    "Frekvens",
    "Taajuus",
    "Czestotliwosc",
    "Frecuencia",
    "Sixnotita",
    "Frekvens",
    "Frecventa",
  },
  { "Polarization",
    "Polarisation",
    "Polarizacija",
    "Polarizzazione",
    "Polarisatie",
    "Polarizao",
    "Polarisation",
    "Polarisasjon",
    "Polarisaatio",
    "Polaryzacja",
    "Polarizacin",
    "Polosi",
    "Polarisation",
    "Polarizare",
  },
  { "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
    "DiSEqC",
  },
  { "Srate",
    "Srate",
    "Srate",
    "Srate",
    "Srate",
    "Srate",
    "Frq. Symbole",
    "Srate",
    "Srate",
    "Srate",
    "Srate",
    "Srate",
    "Srate",
    "Rata simboluri",
  },
  { "Vpid",
    "Vpid",
    "Vpid",
    "Vpid",
    "Vpid",
    "PID de Vdeo",
    "PID Vido",
    "Vpid",
    "Kuva PID",
    "Vpid",
    "Vpid",
    "Vpid",
    "Vpid",
    "PID Video",
  },
  { "Apid1",
    "Apid1",
    "Apid1",
    "Apid1",
    "Apid1",
    "PID udio (1)",
    "PID Audio (1)",
    "Apid1",
    "ni PID1",
    "Apid1",
    "Apid1",
    "Apid1",
    "Apid1",
    "PID Audio (1)",
  },
  { "Apid2",
    "Apid2",
    "Apid2",
    "Apid2",
    "Apid2",
    "Apid2",
    "PID udio (2)",
    "Apid2",
    "ni PID2",
    "Apid2",
    "Apid2",
    "Apid2",
    "Apid2",
    "PID Audio (2)",
  },
  { "Dpid1",
    "Dpid1",
    "Dpid1",
    "Dpid1",
    "Dpid1",
    "PID AC3 (1)",
    "PID AC3 (1)",
    "AC3pid1",
    "AC3 PID1",
    "Dpid1",
    "Dpid1",
    "Dpid1",
    "Dpid1",
    "PID AC3 (1)",
  },
  { "Dpid2",
    "Dpid2",
    "Dpid2",
    "Dpid2",
    "Dpid2",
    "PID AC3 (2)",
    "PID AC3 (2)",
    "AC3pid2",
    "AC3 PID2",
    "Dpid2",
    "Dpid2",
    "Dpid2",
    "Dpid2",
    "PID AC3 (2)",
  },
  { "Tpid",
    "Tpid",
    "Tpid",
    "Tpid",
    "Tpid",
    "PID Teletexto",
    "PID Tltexte",
    "Tekst-TV pid",
    "TekstiTV PID",
    "Tpid",
    "Tpid",
    "Tpid",
    "Tpid",
    "PID Teletext",
  },
  { "CA",
    "CA",
    "CA",
    "CA",
    "CA",
    "Encriptao",
    "Cryptage",
    "Kortleser",
    "Salauskortti",
    "CA",
    "CA",
    "CA",
    "CA",
    "Criptare",
  },
  { "Pnr",
    "Pnr",
    "Pnr",
    "Pnr",
    "Pnr",
    "Nm. Progr.",
    "Num. Progr.",
    "Program Id",
    "Ohjelmatunnus",
    "Pnr",
    "Pnr",
    "Pnr",
    "Pnr",
    "Nr. Prog.",
  },
  // Timer parameters:
  { "Active",
    "Aktiv",
    "Aktivno",
    "Attivo",
    "Actief",
    "Activo",
    "Actif",
    "Aktiv",
    "Aktiivinen",
    "Aktywny",
    "Activo",
    "Energo",
    "Aktiv",
    "Activ",
  },
  { "Channel",
    "Kanal",
    "Kanal",
    "Canale",
    "Kanaal",
    "Canal",
    "Chane",
    "Kanal",
    "Kanava",
    "Kanal",
    "Canal",
    "Kanali",
    "Kanal",
    "Canal",
  },
  { "Day",
    "Tag",
    "Dan",
    "Giorno",
    "Dag",
    "Dia",
    "Jour",
    "Dag",
    "Piv",
    "Dzien",
    "Da",
    "Imera",
    "Dag",
    "Ziua",
  },
  { "Start",
    "Anfang",
    "Zacetek",
    "Inizio",
    "Begin",
    "Inicio",
    "Dbut",
    "Start",
    "Aloitus",
    "Poczatek",
    "Comienzo",
    "Arxi",
    "Brjar",
    "Start",
  },
  { "Stop",
    "Ende",
    "Konec",
    "Fine",
    "Einde",
    "Fim",
    "Fin",
    "Slutt",
    "Lopetus",
    "Koniec",
    "Fin",
    "Telos",
    "Slutar",
    "Stop",
  },
  { "Priority",
    "Prioritt",
    "Prioriteta",
    "Priorita",
    "Prioriteit",
    "Prioridade",
    "Priorit",
    "Prioritet",
    "Prioriteetti",
    "Priorytet",
    "Prioridad",
    "Protereotita",
    "Prioritet",
    "Prioritate",
  },
  { "Lifetime",
    "Lebensdauer",
    "Veljavnost",
    "Durata",
    "Bewaarduur",
    "Durao",
    "Dure de vie",
    "Levetid",
    "Voimassaolo",
    "Trwalosc dni",
    "Durabilidad",
    "Xronos Zois",
    "Speltid",
    "Durata",
  },
  { "File",
    "Datei",
    "Datoteka",
    "Nome",
    "Filenaam",
    "Ficheiro",
    "Fichier",
    "Filnavn",
    "Tiedosto",
    "Plik",
    "Fichero",
    "Arxeio",
    "Filnamn",
    "Fisier",
  },
  { "First day",
    "Erster Tag",
    "Prvi dan",
    "Primo giorno",
    "Eerste dag",
    "Primeiro dia",
    "Premier jour",
    "Frste dag",
    "1. piv",
    "Pierwszy dzien",
    "Primer da",
    "Proti mera",
    "Frsta dag",
    "Prima zi",
  },
  // Error messages:
  { "Channel is being used by a timer!",
    "Kanal wird von einem Timer benutzt!",
    "Urnik zaseda kanal!",
    "Canale occupato da un timer!",
    "Kanaal wordt gebruikt door een timer!",
    "Canal a ser utilizador por um timer!",
    "Cette chane est en cours d'utilisation!",
    "Kanalen er i bruk av en timer!",
    "Kanava on ajastimen kytss!",
    "Kanal jest zajety przez timer nagran",
    "Canal est ocupado por un timer!",
    "To kanali xrisimopiite apo programmatismeni thesi",
    "Kanalen anvnds av en timer!",
    "Canalul este utilizat de un timer!",
  },
  { "Can't switch channel!",
    "Kanal kann nicht umgeschaltet werden!",
    "Ne morem preklopiti kanala!",
    "Impossibile cambiare canale!",
    "Kan geen kanaal wisselen!",
    "No pode mudar de canal!",
    "Impossible de changer de chane!",
    "Ikke mulig  skifte kanal!",
    "Kanavan vaihtaminen ei mahdollista!",
    "Kanal nie moze byc teraz przelaczony!",
    "No puedo cambiar canal!",
    "Den mporo na pao sto kanali!",
    "Omjligt att byta kanal!",
    "Nu pot comuta canalul!",
  },
  { "Timer is recording!",
    "Timer zeichnet gerade auf!",
    "Snemanje po urniku!",
    "Registrazione di un timer in corso!",
    "Timer is aan het opnemen!",
    "Timer a gravar!",
    "Enregistrement en cours!",
    "Timer gjr opptak!",
    "Ajastinnauhoitus kynniss!",
    "Timer nagrywa!",
    "Timer esta grabando!",
    "Ginete progrmamatismeni egrafi!",
    "Timerstyrd inspelning pgr!",
    "Timer-ul este in inregistrare!",
  },
  { "Error while accessing recording!",
    "Fehler beim Ansprechen der Aufzeichnung!",
    "Napaka pri dostopu do posnetka",
    "Errore nel tentativo di acc alla registrazione",
    "Fout bij lezen opname!",
    "Erro ao aceder  gravao",
    "Impossible d'accder  l'enregistrement",
    "Feil under lesing av opptak!",
    "Nauhoituksen toistaminen eponnistui!",
    "Blad - brak dostepu do nagrania!",
    "Error al accesar la grabacin!",
    "Lathos stin evresi tis egrafis!",
    "Det gr inte att lsa inspelningen",
    "Eroare in timpul accesarii inregistrarii",
  },
  { "Error while deleting recording!",
    "Fehler beim Lschen der Aufzeichnung!",
    "Napaka pri odstranjevanju posnetka!",
    "Errore durante la canc del filmato!",
    "Fout bij verwijderen opname!",
    "Erro enquanto apagava uma gravao!",
    "Erreur de suppression de l'enregistrement!",
    "Feil under sletting av opptak!",
    "Nauhoituksen poistaminen eponnistui!",
    "Blad przy usuwaniu nagrania!",
    "Error al borrar la grabacin!",
    "Lathos stin prospathia na svisti i egrafi!",
    "Det gr inte att ta bort inspelningen",
    "Eroare in timpul stergerii inregistrarii!",
  },
  { "*** Invalid Channel ***",
    "*** Ungltiger Kanal ***",
    "*** Neznan kanal ***",
    "*** CANALE INVALIDO ***",
    "*** Ongeldig kanaal ***",
    "*** Canal Invlido! ***",
    "*** Chane invalide! ***",
    "*** Ugyldig Kanal! ***",
    "*** Virheellinen kanavavalinta! ***",
    "*** Niewazny kanal ***",
    "*** Canal invlido ***",
    "*** Kanali akiro ***",
    "*** Felaktig kanal ***",
    "*** Canal invalid ***",
  },
  { "No free DVB device to record!",
    "Keine freie DVB-Karte zum Aufnehmen!",
    "Ni proste DVB naprave za snemanje!",
    "Nessuna card DVB disp per registrare!",
    "Geen vrije DVB kaart om op te nemen!",
    "Nenhuma placa DVB disponivel para gravar!",
    "Pas de carte DVB disponible pour l'enregistrement!",
    "Ingen ledige DVB enheter for opptak!",
    "Ei vapaata vastaanotinta nauhoitusta varten!",
    "Brak wolnej karty DVB do nagrywania!",
    "No hay dispositivo DVB disponible para grabar!",
    "Den iparxi elevteri DVB Karta gia egrafi!",
    "Det finns ingen ledig DVB enhet fr inspelning!",
    "Nu mai sunt dispozitive DVB pentru inregistrare!",
  },
  { "Channel locked (recording)!",
    "Kanal blockiert (zeichnet auf)!",
    "Zaklenjen kanal (snemanje)!",
    "Canale bloccato (in registrazione)!",
    "Kanaal geblokkeerd (neemt op)!",
    "Canal bloqueado (a gravar)!",
    "Chane verrouille (enregistrement en cours)!",
    "Kanalen er lst (opptak)!",
    "Kanava lukittu (nauhoitusta varten)!",
    "Kanal zablokowany (nagrywanie w toku)!",
    "Canal bloqueado (grabando)!",
    "To kanali ine mplokarismeno (Ginete egrafi)!",
    "Kanalen r lst (inspelning pgr)!",
    "Canal blocat (inregistrare)!",
  },
  { "Can't start Transfer Mode!",
    "Transfer-Mode kann nicht gestartet werden!",
    "Ne morem zaceti z prenosnim nacinom",
    "Impossibile iniziare la modalita' di trasferimento!",
    "Kan Transfer-Mode niet starten",
    "Impossvel iniciar modo de transferncia!",
    "Impossible d'utiliser le mode transfert!",
    "Kan ikke starte transfer modus!",
    "Ksittmttmi teknisi ongelmia!",
    "Tryb transferowy jest niemozliwy!",
    "No puedo iniciar modo de transferencia!",
    "Den mpori na arxisi to Transfer-Mode!",
    "Kan inte starta Transfer Mode!",
    "Nu pot porni Modul de Transfer!",
  },
  { "Can't start editing process!",
    "Schnitt kann nicht gestartet werden!",
    "Ne morem zaceti urejanja!",
    "Imposs iniziare processo di modifica",
    "Kan niet beginnen met bewerken!",
    "No pode iniciar a modificao!",
    "Impossible de commencer le montage!",
    "Kan ikke starte redigeringsprosessen!",
    "Muokkauksen aloittaminen ei onnistu!",
    "Uruchamianie montazu jest niemozliwe!",
    "No puedo iniciar proceso de modificacin!",
    "Den mpori na arxisi to kopsimo tis tenias!",
    "Kan inte starta editering!",
    "Nu pot porni procesul de editare!",
  },
  { "Editing process already active!",
    "Schnitt bereits aktiv!",
    "Urejanje je ze aktivno!",
    "Processo di modifica gia` attivo",
    "Bewerken is al actief!",
    "Processo de modificao j activo!",
    "Montage dj en cours!",
    "Redigeringsprosessen er allerede aktiv!",
    "Muokkaus on jo kynniss!",
    "Montaz w toku!",
    "Proceso de modificacin ya fue iniciado!",
    "To kopsimo ti tenias ini idi se litourgia!",
    "Editering r redan aktiv!",
    "Procesul de editare este activ!",
  },
  { "Can't shutdown - option '-s' not given!",
    "Shutdown unmglich - Option '-s' fehlt!",
    "Zaustavitev ni mogoca - opcija '-s' ni podana!",
    "Impossibile spegnere - parametro '-s' non passato",
    "Shutdown onmogelijk - Optie '-s' ontbreekt!",
    "Impossvel desligar - falta a opo '-s'!",
    "Arrt impossible - option '-s' absente!",
    "Kan ikke sl av - startet uten parameteret '-s'!",
    "Ei voida sammuttaa '-s' parametria ei annettu!",
    "Wylaczenie niemozliwe - brak opcji '-s'!",
    "No puedo cortar - opcin '-s' absente!",
    "Den mporo na kliso ton ipologisti. Lipi i parametros '-s'!",
    "Kan inte avsluta, mste anvnda flagga '-s'",
    "Nu pot opri calculatorul - vezi optiunea '-s'",
  },
  { "Low disk space!",
    "Platte beinahe voll!",
    "Zmanjkuje prostora na disku",
    "Poco spazio su disco!",
    "Disk bijna vol!",
    "Espao em disco reduzido!",
    "Disque presque plein!",
    "Lite ledig diskplass!",
    "Kovalevy lhes tynn!",
    "Dysk wkrotce pelny!",
    "Disco casi lleno",
    "O Skliros kontevi na gemisi!",
    "Lgt diskutrymme!",
    "Spatiu scazut pe disc!",
  },
  // Setup pages:
  { "OSD",
    "OSD",
    "OSD",
    "OSD",
    "OSD",
    "OSD",
    "Affichage des menus",
    "OSD",
    "Tekstinytt",
    "OSD",
    "OSD",
    "OSD",
    "OSD",
    "OSD",
  },
  { "EPG",
    "EPG",
    "EPG",
    "EPG",
    "EPG",
    "EPG",
    "Guide des programmes",
    "Programoversikt",
    "Ohjelmaopas",
    "EPG",
    "EPG",
    "EPG",
    "Elektronisk programguide",
    "EPG",
  },
  { "DVB",
    "DVB",
    "DVB",
    "Scheda DVB",
    "DVB",
    "DVB",
    "Cartes DVB",
    "DVB-enheter",
    "DVB",
    "DVB",
    "DVB",
    "DVB",
    "DVB",
    "Placa DVB",
  },
  { "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
    "LNB",
  },
  { "CICAM",
    "CICAM",
    "CICAM",
    "CICAM",
    "CICAM",
    "CICAM",
    "Accs conditionnel",
    "CICAM",
    "CICAM",
    "CICAM",
    "CICAM",
    "CICAM",
    "CICAM",
    "Acces conditionat",
  },
  { "Recording",
    "Aufnahme",
    "Snemanje",
    "Registrazione",
    "Opname",
    "A gravar",
    "Enregistrement",
    "Opptak",
    "Nauhoita",
    "Nagranie",
    "Grabacin",
    "Egrafi",
    "Inspelning",
    "Inregistrare",
  },
  { "Replay",
    "Wiedergabe",
    "Predvajanje",
    "Replay",
    "Afspelen",
    "Replay",
    "Lecture",
    "Spill av",
    "Toista",
    "Odtwarzanie",
    "Poner",
    "Anametadosi",
    "Repris",
    "Redare",
  },
  { "Miscellaneous",
    "Sonstiges",
    "Ostalo",
    "Generici",
    "Overig",
    "Outros",
    "Divers",
    "Forskjellig",
    "Sekalaista",
    "Pozostale",
    "Varios",
    "Diafora",
    "Diverse",
    "Diverse",
  },
  { "Restart",
    "Neustart",
    "Ponoven zagon",
    "Restart",
    "Herstart",
    "Reiniciar",
    "Redmarrer",
    "Start p nytt",
    "Aloita uudelleen",
    "Zastartowac",
    "Reiniciar",
    "Epanekinisi",
    "Omstart",
    "Restart",
  },
  // Setup parameters:
  { "Setup.OSD$Language",
    "Sprache",
    "Jezik",
    "Linguaggio",
    "Taal",
    "Linguagem",
    "Langue",
    "Sprk",
    "Kieli",
    "Jezyk",
    "Lengua",
    "Glosa",
    "Sprk",
    "Limba OSD",
  },
  { "Setup.OSD$Width",
    "Breite",
    "Sirina",
    "Largh OSD",
    "Breedte",
    "Largura",
    "Largeur",
    "Bredde",
    "Leveys",
    "Szerokosc",
    "Anchura",
    "Makros",
    "Bredd",
    "Latime OSD",
  },
  { "Setup.OSD$Height",
    "Hhe",
    "Visina",
    "Altezz OSD",
    "Hoogte",
    "Altura",
    "Hauteur",
    "Hyde",
    "Korkeus",
    "Wysokosc",
    "Altura",
    "Ipsos",
    "Hjd",
    "Inaltime OSD",
  },
  { "Setup.OSD$Message time (s)",
    "Anzeigedauer fr Nachrichten (s)",
    "Cas sporocila (s)",
    "Tempo del messaggio (s)",
    "Weergave duur van berichten (s)",
    "Mostrar contador (s)",
    "Dure affichage cran (s)",
    "Tid meldinger skal vises (s)",
    "Ilmoitusten nkymisaika (s)",
    "Czas wyswietlania wiadomosci (s)",
    "Duracin muestra mensajes (s)",
    "Xronos endiksis minimaton (d)",
    "Tid fr meddelanden (sek)",
    "Timp afisare mesaj (sec)",
  },
  { "Setup.OSD$Channel info position",
    "Kanal-Info Position",
    "Pozicija informacije o kanalu",
    "Posizione info canale",
    "Kanaal info positie",
    "Posio de info dos canais",
    "Position infos chanes",
    "Posisjon p kanalinformasjon",
    "Kanavainfon sijainti",
    "Lokalizacja informacji o kanale",
    "Posicin para informacin canal",
    "Thesi Pliroforias kanalion",
    "Placering av kanalinformation",
    "Pozitie info canal",
  },
  { "Setup.OSD$Info on channel switch",
    "Info beim Kanalwechsel",
    "Pokazi naziv kanala",
    "Vis info nel cambio canale",
    "Kanaal info tonen",
    "Mostrar info ao mudar de Canal",
    "Affichage progr. en cours",
    "Info ved kanalskifte",
    "Nyt kanavainfo",
    "Informacja przy zmianie kanalu",
    "Informacin para cambio de canal",
    "Plirofories stin alagi kanaliou",
    "Information vid kanalbyte",
    "Info despre comutare canal",
  },
  { "Setup.OSD$Scroll pages",
    "Seitenweise scrollen",
    "Drsni meni",
    "Scrolla pagina nel menu",
    "Scrollen per pagina",
    "Scroll da pgina no menu",
    "Affichage progr. suivant",
    "Rask rulling i menyer",
    "Valikkojen rullaus",
    "Przesuwac stronami",
    "Desplazar pgina entera",
    "Scroll selidas",
    "Blddra sidor",
    "Deruleaza pagini",
  },
  { "Setup.OSD$Sort timers",
    "Timer sortieren",
    "Sortiraj termine",
    "Ordinamento timer",
    "Timers sorteren",
    "Ordenar os timers",
    "Trier les programmations",
    "Sorter timere",
    "Jrjest ajastimet",
    "Sortowanie timerow",
    "Ordenar timer",
    "Organosi programmatismenon",
    "Sortera timers",
    "Sortare timere",
  },
  { "Setup.OSD$Recording directories",
    "Aufnahmeverzeichnisse",
    "Direktoriji za posnetke",
    "Directory di registrazione",
    "Opname directories",
    "Directorias de gravao",
    "Dossiers d'enregistrements",
    "Kataloger til opptak",
    "Nauhoitushakemistot",
    "Wykaz nagran",
    "Directorios para grabacin",
    "Fakeli egrafon",
    "Kataloger fr inspelningar",
    "Directoare inregistrari",
  },
  { "Setup.EPG$EPG scan timeout (h)",
    "Zeit bis EPG Scan (h)",
    "Cas do EPG pregleda (h)",
    "Timeout EPG (h)",
    "EPG-scan Timeout (h)",
    "Expirou o EPG (h)",
    "Temps maxi EPG (h)",
    "Ledig tid fr EPG-sk (h)",
    "Ohjelmatied. odotusaika (h)",
    "Czas do skanu EPG (h)",
    "Tiempo hasta exploracin EPG (h)",
    "Xronos mexri sarosi EPG se Ores",
    "EPG skning timeout",
    "Timeout EPG",
  },
  { "Setup.EPG$EPG bugfix level",
    "EPG Fehlerbereinigung",
    "Nivo za popravilo EPG napak",
    "EPG livello corr",
    "EPG foutcorrectieniveau",
    "Nvel de correcto EPG",
    "Niveau de correction EPG",
    "Niv for EPG-feilretting",
    "EPG Bugfix Level",
    "Poziom bledow EPG",
    "Nivel para arreglar EPG",
    "EPG Bugfix Vathmos",
    "Niv fr EPG bugfix",
    "Nivel corectie EPG",
  },
  { "Setup.EPG$Set system time",
    "Systemzeit stellen",
    "Nastavi sistemski cas",
    "Settaggio orario auto",
    "Systeem klok instellen",
    "Ajustar relgio do sistema",
    "Ajuster l'heure du systme",
    "Juster system-klokken",
    "Vastaanota kellonaika",
    "Ustawianie czasu",
    "Ajustar reloj de sistema",
    "Sintonismos Oras ipologosti",
    "Stll in systemtid",
    "Seteaza ceasul sistem",
  },
  { "Setup.EPG$Use time from transponder",
    "Transponder fr Systemzeit",
    "Transponder za nastavitev casa",
    "Utilizza orario da transponder",
    "Gebruik transponder tijd voor systeem",
    "Usar relgio do transponder",
    "Utiliser l'heure de la chane",
    "Bruk klokke fra transponder",
    "Vastaanota kellonaika lhettimelt",
    "Transponder do ustawiania czasu",
    "Transponder para reloj de sistema",
    "Transponder gia sintonismo tis oras",
    "Anvnd klockan frn fransponder",
    "Preia ceasul din transponder",
  },
  { "Setup.DVB$Primary DVB interface",
    "Primres DVB Interface",
    "Primarna naprava",
    "Scheda DVB primaria",
    "Eerste DVB kaart",
    "Interface DVB primrio",
    "Carte DVB primaire",
    "Hoved DVB-enhet",
    "Ensisij. vast.otin",
    "Pierwotny interfejs DVB",
    "Primer interface DVB",
    "Protevon DVB karta",
    "Primr DVB enhet",
    "Placa DVB primara",
  },
  { "Setup.DVB$Video format",
    "Video Format",
    "Video format",
    "Formato video",
    "Videoformaat",
    "Formato vdeo",
    "Format vido",
    "TV-Format",
    "Kuvamuoto",
    "Format telewizyjny",
    "Formato Vdeo",
    "Video Format",
    "Video format",
    "Format Video",
  },
  { "Setup.LNB$SLOF (MHz)",
    "SLOF (MHz)",
    "Frekvenca preklopa (MHz)",
    "SLOF (MHz)",
    "SLOF (MHz)",
    "Limite de bandas LNB (MHz)",
    "Limite de bandes LNB (MHz)",
    "LO-grensefrekvens (MHz)",
    "SLOF (MHz)",
    "SLOF (MHz)",
    "SLOF (MHz)",
    "SLOF (MHz)",
    "SLOF (MHz)",
    "SLOF (MHz)",
  },
  { "Setup.LNB$Low LNB frequency (MHz)",
    "Untere LNB-Frequenz (MHz)",
    "Spodnja LNB-frek. (MHz)",
    "Freq LO LNB (MHz)",
    "Laagste LNB frequentie (MHz)",
    "Frequncia base LNB (MHz)",
    "Frquence basse LNB (MHz)",
    "LO-frekvens i lavbndet (MHz)",
    "LO LNB taajuus (MHz)",
    "Dolna czestotliwosc LNB (MHz)",
    "Frecuencia baja LNB (MHz)",
    "Kato LNB-Sixnotita (MHz)",
    "Undre LNB frekvens (MHz)",
    "Frecvnta LO LNB (Mhz)",
  },
  { "Setup.LNB$High LNB frequency (MHz)",
    "Obere LNB-Frequenz (MHz)",
    "Zgornja LNB-frek. (MHz)",
    "Freq HI LNB (MHz)",
    "Hoogste LNB frequentie (MHz)",
    "Frequncia alta LNB (MHz)",
    "Frquence haute LNB (MHz)",
    "LO-frekvens i hybndet (MHz)",
    "HI LNB taajuus (MHz)",
    "Gorna czestotliwosc LNB (MHz)",
    "Frecuencia alta LNB (MHz)",
    "Ano LNB-Sixnotita (MHz)",
    "vre LNB frekvens (MHz)",
    "Feecventa HI LNB (MHz)",
  },
  { "Setup.LNB$Use DiSEqC",
    "DiSEqC benutzen",
    "Uporabi DiSEqC",
    "Utilizza DiSEqC",
    "DiSEqC gebruiken",
    "Utilizar DiSEqC",
    "Utiliser le DiSEqC",
    "Bruk DiSEqC",
    "Kyt DiSEqC",
    "Uzywac DiSEqC",
    "Utilizar DiSEqC",
    "Energopiisi DiSEqC",
    "Anvnd DiSEqC",
    "Utilizez DiSEqC",
  },
  { "Setup.CICAM$CICAM DVB",
    "CICAM DVB",
    "CICAM DVB",
    "CICAM DVB",
    "CICAM DVB",
    "CICAM DVB",
    "Accs conditionnel",
    "CICAM DVB",
    "CICAM DVB",
    "CICAM DVB",
    "CICAM DVB",
    "CICAM DVB",
    "CICAM DVB",
    "Setare acces conditional",
  },
  { "Setup.Recording$Margin at start (min)",
    "Zeitpuffer bei Anfang (min)",
    "Premor pred zacetkom (min)",
    "Min margine inizio (min)",
    "Tijd marge begin (min)",
    "Margem inicial (min)",
    "Marge antrieure (min)",
    "Opptaksmargin start (min)",
    "Aloitusmarginaali (min)",
    "Poczatkowy czas buforowy (min)",
    "Comenzar grabacin antes (min)",
    "Prosthetos xronos prin arxi (lepta)",
    "Marginal fr start (min)",
    "Margine la pornire (min)",
  },
  { "Setup.Recording$Margin at stop (min)",
    "Zeitpuffer bei Ende (min)",
    "Premor za koncem (min)",
    "Min margine fine (min)",
    "Tijd marge eind (min)",
    "Margem final (min)",
    "Marge postrieure (min)",
    "Opptaksmargin slutt (min)",
    "Lopetusmarginaali (min)",
    "Koncowy czas buforowy (min)",
    "Cortar grabacin despus (min)",
    "Prosthetos xronos sto telos (lepta)",
    "Marginal fr stopp (min)",
    "Margine la oprire (min)",
  },
  { "Setup.Recording$Primary limit",
    "Primr-Limit",
    "Osnovna meja",
    "Limite primario",
    "Eerste grens",
    "Limite Primrio",
    "Premire limite",
    "Prioritetsgrense HovedDVB",
    "PrimaryLimit",
    "Pierwotny limit",
    "L'mite primario",
    "Protevon limit",
    "Primr grns",
    "Limita Primara",
  },
  { "Setup.Recording$Default priority",
    "Default Prioritt",
    "Osnovna prioriteta",
    "Priorita' predefinita",
    "Standaard prioriteit",
    "Prioridade por defeito",
    "Priorit par dfaut",
    "Normal prioritet (Timer)",
    "Oletusprioriteetti",
    "Priorytet pierwotny",
    "Prioridad predefinida",
    "Protereotita",
    "Normal prioritet",
    "Prioritate implicita",
  },
  { "Setup.Recording$Default lifetime (d)",
    "Default Lebensdauer (d)",
    "Osnovni zivljenski cas (d)",
    "Durata predefinita (d)",
    "Standaard levensduur (d)",
    "Validade por defeito (d)",
    "Dure de vie par dfaut (d)",
    "Normal levetid timer (d)",
    "Oletus voimassaoloaika (d)",
    "Pierwotna trwalosc (d)",
    "Duracin predefinida",
    "Xronos zois",
    "Normal livstid",
    "Durata predefinita",
  },
  { "Setup.Recording$Use episode name",
    "Episodenname verwenden",
    "Uporabi ime epizode",
    "Utilizza il nome dell'episodio",
    "Gebruik episode naam",
    "Utilizar o nome do episdio",
    "Utiliser le nom de l'pisode",
    "Bruk episodenavn",
    "Kyt jakson nime",
    "Czy uzywac nazwe epizodu",
    "Utilizar nombre de episodo",
    "Xrisimopiisi onomatos episodiou",
    "Anvnd episodnamn",
    "Utilizeaza numele episodului",
  },
  { "Setup.Recording$Mark instant recording",
    "Direktaufzeichnung markieren",
    "Oznaci direktno snemanje",
    "Marca la registrazione",
    "Direkte opnamen markeren",
    "Marca de gravao rpida",
    "Enregistrement immdiat",
    "Markere direkteopptak",
    "Merkitse vlitn nauh.",
    "Zaznaczyc natychm. nagranie",
    "Marcar grabaciones instantneas",
    "Markarisma apevthias egrafis",
    "Mrk direktinspelning",
    "Inregistrare imediata",
  },
  { "Setup.Recording$Name instant recording",
    "Direktaufzeichnung benennen",
    "Ime za direktno snemanje",
    "Nome registrazione istantanea",
    "Naam direkt-opname",
    "Nome de gravao rpida",
    "Noms enregistr. immdiats",
    "Navngi direkteopptak",
    "Nime vlitn nauh.",
    "Nazwac natychm. nagranie",
    "Nombrar grabaciones instantneas",
    "eponomasi apevthias egrafis",
    "Namnge direktinspelning",
    "Nume inregistrare imediata",
  },
  { "Setup.Recording$Instant rec. time (min)",
    "Dauer der Direktaufzeichnung (min)",
    "",//TODO
    "",//TODO
    "",//TODO
    "",//TODO
    "",//TODO
    "",//TODO
    "",//TODO
    "",//TODO
    "",//TODO
    "",//TODO
    "Direktinspelning lngd (min)",
    "Timpul de inregistarea imediata (min)",
  },
  { "Setup.Recording$Record Dolby Digital",
    "Dolby Digital Ton aufzeichnen",
    "Posnemi dolby digital",
    "Registra dolby digital",
    "Dolby Digital geluid opnamen",
    "Gravar em Dolby Digital",
    "Enregistrer en Dolby Digital",
    "Ta opp Dolby Digital lyd",
    "Dolby Digital nauhoitus",
    "Nagrywac Dolby Digital",
    "Grabar sonido Dolby Digital",
    "Egrafi tou Dolby Digital ixou",
    "Spela in ljud med Dolby Digital",
    "Inregistreaza Dolby Digital",
  },
  { "Setup.Recording$Max. video file size (MB)",
    "Max. Video Dateigre (MB)",
    "Najvecja velikost datoteke (MB)",
    "Dimensione massima file video (MB)",
    "Maximale omvang video file (MB)",
    "Tamanho mximo dos ficheiros (MB)",
    "Taille maxi des fichiers (MB)",
    "Maksimal strrelse p videofiler (MB)",
    "Maksimi tiedoston koko (MB)",
    "Maks. wielkosc pliku (MB)",
    "Tamao mx. ficheros (MB)",
    "Megisto megethos arxeiou (MB)",
    "Maximal filstorlek fr inspelning (MB)",
    "Dimensiune maxima a fisierului video (MB)",
  },
  { "Setup.Recording$Split edited files",
    "Editierte Dateien aufteilen",
    "Razdeli urejene datoteke",
    "Dividi i file modificati",
    "Bewerkte files opdelen",
    "Quebrar ficheiros",
    "Sparer les squences",
    "Splitt redigerte filer",
    "Paloittele muokatut",
    "Dzielic montowane pliki",
    "Quebrar ficheros",
    "Diamelisma epeksergasm. arxeion",
    "Dela upp editerade filer",
    "Separare fisiere editate",
  },
  { "Setup.Replay$Multi speed mode",
    "MultiSpeed Modus",
    "Rezim z vec hitrostmi",
    "Modalita' multispeed",
    "Multi-speed mode",
    "Modo de multi-speed",
    "Mode multi-vitesses",
    "Multispeed modus",
    "Moninopeustila",
    "Tryb wielopredkosciowy",
    "Modo multi-velocidad",
    "Multispeed modus",
    "Multispeed mode",
    "Mod multi-rata",
  },
  { "Setup.Replay$Show replay mode",
    "Wiedergabestatus anzeigen",
    "Prikazi rezim predvajanja",
    "Modalita' di visualizz su replay",
    "Weergave mode aangeven",
    "Mostrar modo de replay",
    "Affichage mode de lecture",
    "Vis avspillingsmodus",
    "Nyt toiston tila",
    "Wyswietlac status odtwarzania",
    "Mostrar modo de replay",
    "Endiksi  status anametadosis",
    "Visa uppspelnings mode",
    "Afiseaza modul de redare",
  },
  { "Setup.Miscellaneous$Min. event timeout (min)",
    "Mindest Event Pause (min)",
    "Najmanjsi cas dogodka (min)",
    "Tempo minimo di pausa (min)", // ??? i don't know...
    "Minimale event time-out (min)",
    "Perodo mnimo de pausa (min)",
    "MinEventTimeout (min)", // Too difficult to translate - read the manual!
    "Minste hendelsespause (min)",
    "Minimi tapahtuman odotus (min)",
    "Min. czas do nast. akcji (Event) (min)",
    "Tiempo mnimo pausa (min)",
    "Elaxistos Xronos paremvolis (lepta)",
    "Minsta hndelse-pause (min)",
    "MinEventTimeout (min)",
  },
  { "Setup.Miscellaneous$Min. user inactivity (min)",
    "Mindest Benutzer-Inaktivitt (min)",
    "Najmanjsi cas neaktivnosti (min)",
    "Tempo minimo di inattivita' (min)",
    "Minimum gebruikers inactiviteit (min)",
    "Perodo mnimo de inactividade (min)",
    "Dure minimale d'inactivit (min)",
    "Minimumstid med inaktivitet (min)",
    "Minimi kyttjn odotus (min)",
    "Min. brak aktywnosci uzytkownika (min)",
    "Tiempo mnimo inactividad (min)",
    "Elaxistos xronos mi xrisis (lepta)",
    "Minsta anndar-inaktivitet (min)",
    "Durata minima de inactivitate (min)",
  },
  { "Setup.Miscellaneous$SVDRP timeout (s)",
    "SVDRP Timeout (s)",
    "SVDRP Timeout (s)",
    "Timeout SVDRP (s)",
    "SVDRP Timeout (s)",
    "Timeout SVDRP (s)",
    "Temps maxi SVDRP (s)",
    "Ubrukt SVDRP-levetid (s)",
    "SVDRP odotusaika (s)",
    "Min. brak aktywnosci SVDRP (s)",
    "SVDRP interrupcin (s)",
    "SVDRP Timeout (d)",
    "SVDRP Timeout (d)",
    "Timeout SVDRP (sec)",
  },
  // The days of the week:
  { "MTWTFSS",
    "MDMDFSS",
    "PTSCPSN",
    "DLMMGVS",
    "MDWDVZZ",
    "STQQSSD",
    "LMMJVSD",
    "MTOTFLS",
    "MTKTPLS",
    "PWSCPSN",
    "LMMJVSD",
    "DTTPPSK",
    "MTOTFLS",
    "LMMJVSD",
  },
  { "MonTueWedThuFriSatSun", // must all be 3 letters!
    "MonDieMitDonFreSamSon",
    "PonTorSreCetPetSobNed",
    "LunMarMerGioVenSabDom",
    "MaaDinWoeDonVryZatZon",
    "SegTerQuaQuiSexSabDom",
    "LunMarMerJeuVenSamDim",
    "ManTirOnsTorFreLrSn",
    "MaaTiiKesTorPerLauSun",
    "PonWtoSroCzwPiaSobNie",
    "LunMarMieJueVieSabDom",
    "DevTriTetPemParSavKir",
    "MnTisOnsTorFreLrSn",
    "LunMarMieJoiVinSimDum",
  },
  // The allowed characters in strings:
  { " abcdefghijklmnopqrstuvwxyz0123456789-.#~",
    " abcdefghijklmnopqrstuvwxyz0123456789-.#~",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    " abcdefghijklmnopqrstuvwxyz0123456789-.#~",
    "",// TODO
    " abcdefghijklmnopqrstuvxyz0123456789-.#~",
    " abcdefghijklmnopqrstuvwxyz0123456789-.#~",
  },
  // Learning keys:
  { "Learning Remote Control Keys",
    "Fernbedienungs-Codes lernen",
    "Ucim se kod upravljalca",
    "Apprendimento tasti unita` remota",
    "Leren toetsen afstandsbediening",
    "Aprender as teclas do telecomando",
    "Apprentissage des codes de tlcommande",
    "Lre fjernkontrolltaster",
    "Kaukostimen nppinten opettelu",
    "Nauka kodu pilota",
    "Aprendiendo teclas del telemando",
    "Ekmathisi Remote Control",
    "Inlrning av fjrrkontrollsknappar",
    "Invatare taste telecomanda",
  },
  { "Phase 1: Detecting RC code type",
    "Phase 1: FB Code feststellen",
    "Faza 1: Sprejemanje IR kode",
    "Fase 1: tipo ricevitore RC",
    "Fase 1: detecteren type afstandsbediening",
    "Fase 1: detectar tipo de receptor",
    "Phase 1: Dtection du type de code",
    "Fase 1: Finne fjernkontroll-kodetype",
    "Vaihe 1: Lhetystavan selvittminen",
    "Faza 1: Detekcja typu kodu",
    "Fase 1: Detectando tipo de receptor",
    "Phasi 1: Dilosi RC Code",
    "Steg1: identifiering av RC kod",
    "Faza 1: Detectie tip telecomanda",
  },
  { "Press any key on the RC unit",
    "Eine Taste auf der FB drcken",
    "Pritisnite tipko na upravljalcu",
    "Premere un tasto nell'unita` RC",
    "Druk op een willekeurige knop",
    "Pressione qualquer tecla do telecomando",
    "Appuyer sur une touche de la tlcommande",
    "Trykk en av tastene p fjernkontrollen",
    "Paina mit tahansa kaukostimen nppint",
    "Nacisnac klawisz pilota",
    "Pulse una tecla en el telemando",
    "Pata ena pliktro sto RC",
    "Tryck valfri tangent p fjrrkontrollen",
    "Apasati o tasta pe telecomanda",
  },
  { "RC code detected!",
    "FB Code erkannt!",
    "IR koda sprejeta!",
    "Codice RC rilevato!",
    "Afstandsbediening code herkend!",
    "Cdigo do telecomando detectado!",
    "Code de la tlcommande dtect!",
    "Fjernkontroll-kodetype funnet!",
    "Nppinpainallus vastaanotettu!",
    "Kod pilota zostal poznany!",
    "Cdigo detectado!",
    "Evresi RC Code!",
    "RC koden detekterad!",
    "S-a detectat tipul telecomenzii!",
  },
  { "Do not press any key...",
    "Keine Taste drcken...",
    "Ne pritiskajte tipk...",
    "Non premere alcun tasto...",
    "Druk niet op een knop...",
    "No pressione nada...",
    "N'appuyer sur aucune touche ...",
    "Ikke trykk p noen av tastene...",
    "l paina mitn nppint...",
    "Nie naciskac klawiszy...",
    "No pulse tecla...",
    "Min patas Pliktra...",
    "Tryck inte p ngon knapp...",
    "Nu apasati nicio tasta...",
  },
  { "Phase 2: Learning specific key codes",
    "Phase 2: Einzelne Tastencodes lernen",
    "Faza 2: Ucenje posebnih kod",
    "Fase 2: Codici specifici dei tasti",
    "Fase 2: Leren specifieke toets-codes",
    "Fase 2: A aprender cdigos especificos",
    "Phase 2: Apprentissage des codes des touches",
    "Fase 2: Lre spesifikke tastekoder",
    "Vaihe 2: Nppinkoodien opettelu",
    "Faza 2: Nauka pojedynczych klawiszy",
    "Fase 2: Aprendiendo cdigos especficos",
    "Fasi 2: Ekmathisi memonomenon kodikon pliktron",
    "Fas 2: Inlrning av specifika knapp koder",
    "Faza 2: Invatarea codurilor specifice tastelor",
  },
  { "Press key for '%s'",
    "Taste fr '%s' drcken",
    "Pritisnite tipko za '%s'",
    "Premere il tasto per '%s'",
    "Druk knop voor '%s'",
    "Pressione tecla para '%s'",
    "Appuyer sur la touche '%s'",
    "Trykk tasten for '%s'",
    "Paina nppint toiminnolle '%s'",
    "Nacisnac klawisz dla '%s'",
    "Pulsar tecla para '%s'",
    "Pata to pliktro gia '%s'",
    "Tryck p knappen fr '%s'",
    "Apasati tasta pentru '%s'",
  },
  { "Press 'Up' to confirm",
    "'Auf' drcken zum Besttigen",
    "Pritisnite tipko 'Gor' za potrditev",
    "Premere 'Su' per confermare",
    "Druk 'Omhoog' om te bevestigen",
    "Pressione 'Cima' para confirmar",
    "Appuyer sur 'Haut' pour confirmer",
    "Trykk 'Opp' for  bekrefte",
    "Paina 'Yls' hyvksyksesi",
    "Nacisnac 'Gora' do potwierdzenia",
    "Pulse 'Arriba' para confirmar",
    "Pata 'pano' gia apodoxi",
    "Tryck 'Upp' fr att bekrfta",
    "Apsati 'Sus' pentru confirmare",
  },
  { "Press 'Down' to continue",
    "'Ab' drcken zum Weitermachen",
    "Pritisnite tipko 'Dol' za nadaljevanje",
    "Premere 'Giu' per confermare",
    "Druk 'Omlaag' om verder te gaan",
    "Pressione 'Baixo' para continuar",
    "Appuyer sur 'Bas' pour continuer",
    "Trykk Ned' for  fortsette",
    "Paina 'Alas' jatkaaksesi",
    "Nacisnac 'Dol' zeby kontynuowac",
    "Pulse 'Abajo' para confirmar",
    "Pata 'kato' gia sinexia",
    "Tryck 'Ner' fr att bekrfta",
    "Apasati jos pentru continuare",
  },
  { "(press 'Up' to go back)",
    "('Auf' drcken um zurckzugehen)",
    "(pritisnite 'Gor' za nazaj)",
    "(premere 'Su' per tornare indietro)",
    "(druk 'Omhoog' om terug te gaan)",
    "(Pressione 'Cima' para voltar)",
    "(Appuyer sur 'Haut' pour revenir en arrire)",
    "(trykk 'Opp' for  g tilbake)",
    "(paina 'Yls' palataksesi takaisin)",
    "(Nacisnac 'Gora' cofa)",
    "(Pulse 'Arriba' para retornar)",
    "(Pata 'pano' gia na pas piso)",
    "(Tryck 'Upp' fr att backa)",
    "(Apsati 'Sus' pentru revenire)",
  },
  { "(press 'Down' to end key definition)",
    "('Ab' drcken zum Beenden)",
    "(pritisnite 'Dol' za konec)",
    "('Giu' per finire la definiz tasti)",
    "(Druk 'Omlaag' om te beeindigen)",
    "(Pressione 'Baixo' para terminar a definio)",
    "(Appuyer sur 'Bas' pour terminer)",
    "(trykk 'Ned' for  avslutte innlring)",
    "(paina 'Alas' lopettaaksesi nppinten opettelun)",
    "(Nacisnac 'Dol' by zakonczyc)",
    "(Pulse 'Abajo' para terminar programacin teclas)",
    "(Pata 'Kato' gia termatismo)",
    "(Tryck 'Ner' fr att avsluta knapp definition)",
    "(Apasati 'Jos' pentru terminare)",
  },
  { "Phase 3: Saving key codes",
    "Phase 3: Codes abspeichern",
    "Faza 3: Shranjujem kodo",
    "Fase 3: Salvataggio key codes",
    "Fase 3: Opslaan toets codes",
    "Fase 3: A salvar os cdigos das teclas",
    "Phase 3: Sauvegarde des codes des touches",
    "Fase 3: Lagre tastekoder",
    "Vaihe 3: Nppinkoodien tallettaminen",
    "Faza 3: Zapamietac Kod",
    "Fase 3: Guardar cdigos de teclas",
    "Fasi 3: Apothikevsi kodikon",
    "Fas 3: Spara knappkoder",
    "Faza 3: Salvarea codurilor de taste",
  },
  { "Press 'Up' to save, 'Down' to cancel",
    "'Auf' speichert, 'Ab' bricht ab",
    "'Gor' za potrditev, 'Dol' za prekinitev",
    "'Su' per salvare, 'Giu' per annullare",
    "'Omhoog' te bewaren, 'Omlaag' voor annuleren",
    "'Cima' para Salvar, 'Baixo' para Cancelar",
    "Appuyer sur 'Haut' pour sauvegarder, 'Bas' pour annuler",
    "Trykk 'Opp' for  lagre, 'Ned' for  avbryte",
    "Paina 'Yls' tallettaaksesi ja 'Alas' peruuttaaksesi",
    "'Gora' zapamietuje, 'Dol' przerywa",
    "Pulse 'Arriba' para guarder, 'Abajo' para anular",
    "'kato' apothikevsi, 'Pano' akirosi",
    "Tryck 'Upp' fr att spara, 'Ner' fr att avsluta",
    "Apsati 'Sus' pentru salvare, 'Jos' pentru anulare",
  },
  // Key names:
  { "Up",
    "Auf",
    "Gor",
    "Su",
    "Omhoog",
    "Cima",
    "Haut",
    "Opp",
    "Yls",
    "Gora",
    "Arriba",
    "Pano",
    "Upp",
    "Sus",
  },
  { "Down",
    "Ab",
    "Dol",
    "Giu",
    "Omlaag",
    "Baixo",
    "Bas",
    "Ned",
    "Alas",
    "Dol",
    "Abajo",
    "Kato",
    "Ner",
    "Jos",
  },
  { "Menu",
    "Men",
    "Meni",
    "Menu",
    "Menu",
    "Menu",
    "Menu",
    "Meny",
    "Valikko",
    "Menu",
    "Menu",
    "Menou",
    "Meny",
    "Meniu",
  },
  { "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
    "Ok",
  },
  { "Back",
    "Zurck",
    "Nazaj",
    "Indietro",
    "Terug",
    "Voltar",
    "Retour",
    "Tilbake",
    "Takaisin",
    "Wstecz",
    "Retornar",
    "Piso",
    "Tillbaka",
    "Inapoi",
  },
  { "Left",
    "Links",
    "Levo",
    "Sinistra",
    "Links",
    "Esquerda",
    "Gauche",
    "Venstre",
    "Vasemmalle",
    "Lewo",
    "Izquierda",
    "Aristera",
    "Vnster",
    "Stinga",
  },
  { "Right",
    "Rechts",
    "Desno",
    "Destra",
    "Rechts",
    "Direita",
    "Droite",
    "Hyre",
    "Oikealle",
    "Prawo",
    "Derecha",
    "Deksia",
    "Hger",
    "Dreapta",
  },
  { "Red",
    "Rot",
    "Rdeca",
    "Rosso",
    "Rood",
    "Vermelho",
    "Rouge",
    "Rd",
    "Punainen",
    "Czerwony",
    "Rojo",
    "Kokino",
    "Rd",
    "Rosu",
  },
  { "Green",
    "Grn",
    "Zelena",
    "Verde",
    "Groen",
    "Verde",
    "Vert",
    "Grnn",
    "Vihre",
    "Zielony",
    "Verde",
    "Prasino",
    "Grn",
    "Verde",
  },
  { "Yellow",
    "Gelb",
    "Rumena",
    "Giallo",
    "Geel",
    "Amarelo",
    "Jaune",
    "Gul",
    "Keltainen",
    "Zolty",
    "Amarillo",
    "Kitrino",
    "Gul",
    "Galben",
  },
  { "Blue",
    "Blau",
    "Modra",
    "Blu",
    "Blauw",
    "Azul",
    "Bleu",
    "Bl",
    "Sininen",
    "Niebieski",
    "Azul",
    "Mple",
    "Bl",
    "Albastru",
  },
  { "Power",
    "Ausschalten",
    "Izklop",
    "Power",
    "Uitschakelen",
    "Ligar",
    "Arrt",
    "Power",
    "Virtakytkin",
    "Wylaczyc",
    "Corriente",
    "Klisimo",
    "P/Av",
    "Pornit",
  },
  { "Volume+",
    "Lautstrke+",
    "Glasnost+",
    "Volume+",
    "Volume+",
    "Volume+",
    "Volume+",
    "Volum+",
    "nenvoimakkuus+",
    "Glosnej",
    "Volumen+",
    "Entasi+",
    "Volym+",
    "Volum+",
  },
  { "Volume-",
    "Lautstrke-",
    "Glasnost-",
    "Volume-",
    "Volume-",
    "Volume-",
    "Volume-",
    "Volum-",
    "nenvoimakkuus-",
    "Ciszej",
    "Volumen-",
    "Entasi-",
    "Volym-",
    "Volum-",
  },
  { "Mute",
    "Stumm",
    "Izklop zvoka",
    "Mute",
    "Geluid onderbreken",
    "Sem som",
    "Coupure du son",
    "Lyd av",
    "nen vaimennus",
    "Cisza",
    "Mudo",
    "Mougko",
    "Ljud Av",
    "Mut(e)",
  },
  // Miscellaneous:
  { "yes",
    "ja",
    "da",
    "si",
    "ja",
    "sim",
    "oui",
    "ja",
    "kyll",
    "tak",
    "s",
    "nai",
    "ja",
    "da",
  },
  { "no",
    "nein",
    "ne",
    "no",
    "nee",
    "no",
    "non",
    "nei",
    "ei",
    "nie",
    "no",
    "oxi",
    "nej",
    "nu",
  },
  { "top",
    "oben",
    "zgoraj",
    "limite sup",
    "boven",
    "topo",
    "haut",
    "vre",
    "yl",
    "gora",
    "parte sup.",
    "pano",
    "vre",
    "sus",
  },
  { "bottom",
    "unten",
    "spodaj",
    "limite inf",
    "onder",
    "fundo",
    "bas",
    "nedre",
    "ala",
    "dol",
    "fondo",
    "kato",
    "nedre",
    "jos",
  },
  { "Disk",
    "Disk",
    "Disk",
    "Disk",
    "Disk",
    "Disk",
    "Disque",
    "Disk",
    "Disk",
    "Disk",
    "Disco",
    "Disk",
    "Disk",
    "Disc",
  },
  { "free",
    "frei",
    "prosto",
    "liberi",
    "vrij",
    "livre",
    "restant",
    "ledig",
    "vapaa",
    "pozostalo",
    "libre",
    "akoma",
    "ledigt",
    "liber",
  },
  { "Jump: ", // note the trailing blank
    "Springen: ",
    "Skoci: ",
    "Vai a: ",
    "Springen: ",
    "Saltar: ",
    "Accs direct: ",
    "Hopp: ",
    "Hypp: ",
    "Skok: ",
    "Saltar: ",
    "Pidima: ",
    "Hopp: ",
    "Salt: ",
  },
  { "Volume ", // note the trailing blank
    "Lautstrke ",
    "Glasnost ",
    "Volume ",
    "Volume ",
    "Volume ",
    "Volume ",
    "Volum ",
    "nenvoimakkuus ",
    "Glosnosc ",
    "Volumen ",
    "Entasi ",
    "Volym ",
    "Volum ",
  },
  { " Stop replaying", // note the leading blank!
    " Wiedergabe beenden",
    " Prekini ponavljanje",
    " Interrompi riproduzione",
    " Stop afspelen",
    " Parar reproduo",
    " Arrter la lecture",
    " Stopp avspilling",
    " Pysyt toisto",
    " Zatrzymac odtwarzanie",
    " Parar reproducin",
    " Telos anametadosis",
    " Avsluta uppspelning",
    " Opreste redare",
  },
  { " Stop recording ", // note the leading and trailing blanks!
    " Aufzeichnung beenden ",
    " Prekini shranjevanje ",
    " Interrompi registrazione ",
    " Stop opnemen ",
    " Parar gravao ",
    " Arrter l'enregistrement ",
    " Stopp opptak fra ",
    " Pysyt nauhoitus ",
    " Zatrzymac nagrywanie ",
    " Parar grabacin ",
    " Telos egrafis ",
    " Avsluta inspelning ",
    " Opreste inregistrarea ",
  },
  { " Cancel editing", // note the leading blank!
    " Schneiden abbrechen",
    " Prekini urejanje",
    " Annulla modifiche",
    " Bewerken afbreken",
    " Anular modificao",
    " Annuler le montage",
    " Avbryt redigering",
    " Peruuta muokkaus",
    " Przerwac montaz",
    " Anular modificacin",
    " Diakopi kopsimatos",
    " Avbryt editering",
    " Opreste editare",
  },
  { "Switching primary DVB...",
    "Primres Interface wird umgeschaltet...",
    "Preklapljanje primarne naprave...",
    "Cambio su card DVB primaria...",
    "Eerste DVB-kaart wordt omgeschakeld...",
    "A mudar interface DVB primrio...",
    "Changement de carte DVB primaire...",
    "Bytter frste DVB-enhet...",
    "Vaihdetaan ensisijainen vastaanotin...",
    "Pierwszy interfejs DVB przelacza...",
    "Cambio interface primario...",
    "I protevon DVB Karta alazi...",
    "Byter primr DVB enhet...",
    "Comuta interfata primara DVB...",
  },
  { "Up/Dn for new location - OK to move",
    "Auf/Ab fr neue Position - dann OK",
    "Gor/Dol za novo poz. - Ok za premik",
    "Su/Giu per nuova posizione - OK per muovere",
    "Gebruik Omhoog/Omlaag - daarna Ok",
    "Cima/Baixo para nova localizao - Ok para mover",
    "Haut/Bas -> nouvelle place - OK -> dplacer",
    "Opp/Ned for ny plass - OK for  flytte",
    "Yls/Alas = liiku, OK = siirr",
    "Gora/Dol na nowa pozycje - Ok zmienia",
    "Arriba/Abajo para nuevo lugar - OK para mover",
    "Pano/Kato gia nea thesi. meta OK",
    "Upp/Ner fr ny plats - OK fr att flytta",
    "Sus/Jos pentru noua locatie - OK pentru a muta",
  },
  { "Editing process started",
    "Schnitt gestartet",
    "Urejanje se je zacelo",
    "Processo di modifica iniziato",
    "Bewerken is gestart",
    "Processo de modificao iniciado",
    "Opration de montage lance",
    "Redigeringsprosess startet",
    "Muokkaus aloitettu",
    "Uruchomiony proces montazu",
    "Proceso modificacin iniciado",
    "Arxi kopsimatos",
    "Editering startad",
    "Procesul de editare a inceput",
  },
  { "Editing process finished",
    "Schnitt beendet",
    "Proces urejanja koncan",
    "Processo di modifica terminato",
    "Bewerken is klaar",
    "Processo de modificao terminado",
    "Montage termin",
    "Redigeringsprosess avsluttet",
    "Muokkaus lopetettu",
    "Proces montazu zakonczony",
    "Proceso modificacion terminado",
    "To kopsimo termatistike",
    "Editering avslutad",
    "Procesul de editare s-a terminat",
  },
  { "Editing process failed!",
    "Schnitt gescheitert!",
    "Napaka pri procesu urejenja!",
    "Processo di modifica fallito!",
    "Bewerken is mislukt!",
    "Falha no processo de modificao",
    "Echec du montage!",
    "Feil under redigering!",
    "Muokkaus eponnistui!",
    "Bledny proces montazu!",
    "Modificacin ha fallado!",
    "Kopsimo apetixe!",
    "Editeringsprocessen misslyckades",
    "Proces de editare nereusit",
  },
  { "scanning recordings...",
    "Aufzeichnungen werden durchsucht...",
    "iskanje posnetkov...",
    "scansione registrazioni...",
    "Doorzoeken opnames...",
    "A pesquisar gravaes...",
    "Recherche des enregistrements...",
    "Gr igjennom opptakene...",
    "haetaan nauhoituksia...",
    "Skan nagran...",
    "buscando grabaciones...",
    "Ginete sarosi egrafon...",
    "Sker igenom inspelningarna...",
    "Caut inregistrari...",
  },
  { NULL }
  };

const char *tr(const char *s)
{
  if (Setup.OSDLanguage) {
     for (const tPhrase *p = Phrases; **p; p++) {
         if (strcmp(s, **p) == 0) {
            const char *t = (*p)[Setup.OSDLanguage];
            if (t && *t)
               return t;
            }
         }
     esyslog(LOG_ERR, "no translation found for '%s' in language %d (%s)\n", s, Setup.OSDLanguage, Phrases[0][Setup.OSDLanguage]);
     }
  const char *p = strchr(s, '$');
  return p ? p + 1 : s;
}

const char * const * Languages(void)
{
  return &Phrases[0][0];
}

